@@ -1,9 +1,4 @@
-use crate::{
-    execute::execute_with_parameters,
-    handles::{self, Statement, StatementImpl},
-    parameter_collection::ParameterCollection,
-    CursorImpl, Error, Preallocated, Prepared,
-};
+use crate::{CursorImpl, Error, Preallocated, Prepared, execute::execute_with_parameters, handles::{self, State, Statement, StatementImpl}, parameter_collection::ParameterCollection};
 use std::{borrow::Cow, thread::panicking};
 use widestring::{U16Str, U16String};
 
@@ -11,7 +6,7 @@ impl<'conn> Drop for Connection<'conn> {
     fn drop(&mut self) {
         match self.connection.disconnect() {
             Ok(()) => (),
-            Err(Error::Diagnostics(record)) if record.is_invalid_state_transaction() => {
+            Err(Error::Diagnostics(record)) if record.state == State::INVALID_STATE_TRANSACTION => {
                 // Invalid transaction state. Let's rollback the current transaction and try again.
                 if let Err(e) = self.connection.rollback() {
                     // Avoid panicking, if we already have a panic. We don't want to mask the original
@@ -230,17 +225,16 @@ impl<'c> Connection<'c> {
     /// See: <https://docs.microsoft.com/en-us/sql/odbc/reference/develop-app/multithreading?view=sql-server-ver15>
     ///
     /// This function may be removed in future versions of this crate and connections would be
-    /// `Send` and `Sync` out of the Box. This will require sufficient testing in which a wide
-    /// variety of database drivers prove to be thread safe. For now this API tries to error on the
-    /// side of caution, and leaves the amount of trust you want to put in the driver implementation
-    /// to the user. I have seen this go wrong in the past, but time certainly improved the
-    /// situation. At one point this will be cargo cult and Connection can be `Send` and `Sync` by
-    /// default (hopefully).
+    /// `Send` out of the Box. This will require sufficient testing in which a wide variety of
+    /// database drivers prove to be thread safe. For now this API tries to error on the side of
+    /// caution, and leaves the amount of trust you want to put in the driver implementation to the
+    /// user. I have seen this go wrong in the past, but time certainly improved the situation. At
+    /// one point this will be cargo cult and Connection can be `Send` by default (hopefully).
     ///
     /// Note to users of `unixodbc`: You may configure the threading level to make unixodbc
-    /// synchronize access to the driver (and thereby making them thread safe if they are not
-    /// thread safe by themself. This may however hurt your performance if the driver would actually
-    /// be able to perform operations in parallel.
+    /// synchronize access to the driver (and thereby making them thread safe if they are not thread
+    /// safe by themself. This may however hurt your performance if the driver would actually be
+    /// able to perform operations in parallel.
     ///
     /// See: <https://stackoverflow.com/questions/4207458/using-unixodbc-in-a-multithreaded-concurrent-setting>
     pub unsafe fn promote_to_send(self) -> force_send_sync::Send<Self> {
@@ -250,7 +244,7 @@ impl<'c> Connection<'c> {
 
 /// You can use this method to escape a password so it is suitable to be appended to an ODBC
 /// connection string as the value for the `PWD` attribute. This method is only of interest for
-/// need to create their own connection strings.
+/// application in need to create their own connection strings.
 ///
 /// See: <https://stackoverflow.com/questions/22398212/escape-semicolon-in-odbc-connection-string-in-app-config-file>
 ///
