@@ -13,7 +13,7 @@ use odbc_api::{
         AnyColumnView, AnyColumnViewMut, BufferDescription, BufferKind, ColumnarRowSet, Indicator,
         TextRowSet,
     },
-    handles::Statement,
+    handles::{OutputStringBuffer, Statement},
     parameter::{VarBinaryArray, VarCharArray, VarCharSlice},
     sys, ColumnDescription, Cursor, DataType, InputParameter, IntoParameter, Nullability, Nullable,
     U16String,
@@ -2427,7 +2427,9 @@ fn escape_hatch(profile: &Profile) {
 #[test_case(SQLITE_3; "SQLite 3")]
 fn varchar_null(profile: &Profile) {
     let table_name = "VarcharNull";
-    let conn = ENV.connect_with_connection_string(profile.connection_string).unwrap();
+    let conn = ENV
+        .connect_with_connection_string(profile.connection_string)
+        .unwrap();
     setup_empty_table(&conn, profile.index_type, table_name, &["VARCHAR(10)"]).unwrap();
 
     let insert = format!("INSERT INTO {} (a) VALUES (?)", table_name);
@@ -2438,6 +2440,47 @@ fn varchar_null(profile: &Profile) {
     assert_eq!("NULL", actual)
 }
 
+/// Connect to database with connection string, and check the output connection string with
+/// attributes complemented by the driver.
+#[test_case(MSSQL; "Microsoft SQL Server")]
+#[test_case(MARIADB; "Maria DB")]
+#[test_case(SQLITE_3; "SQLite 3")]
+fn get_full_connection_string(profile: &Profile) {
+    let mut completed_connection_string = OutputStringBuffer::with_buffer_size(1023);
+    ENV.driver_connect(
+        profile.connection_string,
+        Some(&mut completed_connection_string),
+        odbc_api::DriverCompleteOption::NoPrompt,
+    )
+    .unwrap();
+
+    assert!(!completed_connection_string.is_truncated());
+
+    let completed_connection_string = completed_connection_string.to_utf8();
+
+    // Additional attributes should make the string larger.
+    assert!(profile.connection_string.len() <= completed_connection_string.len());
+}
+
+/// We must be able to detect truncation in case we provide a buffer too small to hold the output
+/// connection string
+#[test_case(MSSQL; "Microsoft SQL Server")]
+// #[test_case(MARIADB; "Maria DB")] STATUS_TACK_BUFFER_OVERRUN
+// #[test_case(SQLITE_3; "SQLite 3")] Does not write truncated connection string at all
+fn get_full_connection_string_truncated(profile: &Profile) {
+    let mut completed_connection_string = OutputStringBuffer::with_buffer_size(1);
+    ENV.driver_connect(
+        profile.connection_string,
+        Some(&mut completed_connection_string),
+        odbc_api::DriverCompleteOption::NoPrompt,
+    )
+    .unwrap();
+
+    eprintln!("Output connection string: {}", completed_connection_string.to_utf8());
+
+    assert!(completed_connection_string.is_truncated());
+}
+
 /// This test is inspired by a bug caused from a fetch statement generating a lot of diagnostic
 /// messages.
 #[test]
